@@ -46,10 +46,12 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/max_limit_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/pecan_debug').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_designate_config('service:api/enabled_extensions_v1').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value('<SERVICE DEFAULT>')
         is_expected.to_not contain_designate__keystone__authtoken('designate_config')
+        is_expected.to contain_oslo__middleware('designate_config').with(
+          :enable_proxy_headers_parsing => '<SERVICE DEFAULT>'
+        )
       end
     end
 
@@ -70,9 +72,9 @@ describe 'designate::api' do
           :default_limit_v2              => '25',
           :max_limit_v2                  => '1500',
           :pecan_debug                   => true,
-          :enabled_extensions_v1         => 'diagnostics,quotas,reports,sync,touch',
-          :enabled_extensions_v2         => 'experimental',
-          :enabled_extensions_admin      => 'reports,quotas,counts,tenants,target_sync',
+          :enabled_extensions_v2         => 'ext1,ext2',
+          :enabled_extensions_admin      => 'reports,quotas,zones',
+          :enable_proxy_headers_parsing  => true,
         })
       end
 
@@ -91,9 +93,25 @@ describe 'designate::api' do
         is_expected.to contain_designate_config('service:api/default_limit_v2').with_value(params[:default_limit_v2])
         is_expected.to contain_designate_config('service:api/max_limit_v2').with_value(params[:max_limit_v2])
         is_expected.to contain_designate_config('service:api/pecan_debug').with_value(params[:pecan_debug])
-        is_expected.to contain_designate_config('service:api/enabled_extensions_v1').with_value(params[:enabled_extensions_v1])
         is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value(params[:enabled_extensions_v2])
         is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value(params[:enabled_extensions_admin])
+        is_expected.to contain_oslo__middleware('designate_config').with(
+          :enable_proxy_headers_parsing => params[:enable_proxy_headers_parsing]
+        )
+      end
+    end
+
+    context 'with enabled_extentions in list' do
+      before do
+        params.merge!({
+          :enabled_extensions_v2    => ['ext1', 'ext2'],
+          :enabled_extensions_admin => ['reports', 'quotas', 'zones']
+        })
+      end
+
+      it 'configure service_api' do
+        is_expected.to contain_designate_config('service:api/enabled_extensions_v2').with_value('ext1,ext2')
+        is_expected.to contain_designate_config('service:api/enabled_extensions_admin').with_value('reports,quotas,zones')
       end
     end
 
